==> libreoffice-l10n_4.2.7.orig.tar.xz: libreoffice-4.2.7/include/sfx2/sfxcommands.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */
#ifndef INCLUDED_SFX2_SFXCOMMANDS_H
#define INCLUDED_SFX2_SFXCOMMANDS_H

#define CMD_SID_ABOUT                               ".uno:About"
#define CMD_SID_NEWDOC                              ".uno:NewDoc"
#define CMD_SID_BROWSE_BACKWARD                     ".uno:BrowseBackward"
#define CMD_SID_BROWSE_FORWARD                      ".uno:BrowseForward"
#define CMD_SID_CLOSEWIN                            ".uno:CloseWin"
#define CMD_SID_COPY                                ".uno:Copy"
#define CMD_SID_CUT                                 ".uno:Cut"
#define CMD_SID_DELETE                              ".uno:Delete"
#define CMD_SID_BASICIDE_DELETECURRENT              ".uno:DeleteCurrent"
#define CMD_SID_STYLE_DESIGNER                      ".uno:DesignerDialog"
#define CMD_SID_EDITDOC                             ".uno:EditDoc"
#define CMD_SID_STYLE_EDIT                          ".uno:EditStyle"
#define CMD_SID_WIN_FULLSCREEN                      ".uno:FullScreen"
#define CMD_SID_BASICIDE_HIDECURPAGE                ".uno:HideCurPage"
#define CMD_SID_HYPERLINK_DIALOG                    ".uno:HyperlinkDialog"
#define CMD_SID_BASICIDE_MODULEDLG                  ".uno:ModuleDialog"
#define CMD_SID_NAVIGATOR                           ".uno:Navigator"
#define CMD_SID_BASICIDE_NEWDIALOG                  ".uno:NewDialog"
#define CMD_SID_BASICIDE_NEWMODULE                  ".uno:NewModule"
#define CMD_SID_OBJECT                              ".uno:ObjectMenue"
#define CMD_SID_OPENDOC                             ".uno:Open"
#define CMD_SID_WEBHTML                             ".uno:WebHtml"
#define CMD_SID_GALLERY_BG_BRUSH                    ".uno:BackgroundImage"
#define CMD_SID_OPENHYPERLINK                       ".uno:OpenHyperlink"
#define CMD_SID_DOCINFO_TITLE                       ".uno:DocInfoTitle"
#define CMD_SID_OPENTEMPLATE                        ".uno:OpenTemplate"
#define CMD_SID_CHECKOUT                            ".uno:CheckOut"
#define CMD_SID_CANCELCHECKOUT                      ".uno:CancelCheckOut"
#define CMD_SID_CHECKIN                             ".uno:CheckIn"
#define CMD_SID_OPENURL                             ".uno:OpenUrl"
#define CMD_SID_OPTIONS                             ".uno:Options"
#define CMD_SID_TEMPLATE_MENU                       ".uno:TemplateMenu"
#define CMD_SID_ORGANIZER                           ".uno:Organizer"
#define CMD_SID_PASTE                               ".uno:Paste"
#define CMD_SID_PASTE_SPECIAL                       ".uno:PasteSpecial"
#define CMD_SID_PASTE_ONLY                          ".uno:PasteOnly"
#define CMD_SID_PASTE_ONLY_VALUE                    ".uno:PasteOnlyValue"
#define CMD_SID_PASTE_ONLY_TEXT                     ".uno:PasteOnlyText"
#define CMD_SID_PASTE_ONLY_FORMULA                  ".uno:PasteOnlyFormula"
#define CMD_SID_PRINTPREVIEW                        ".uno:PrintPreview"
#define CMD_SID_RELOAD                              ".uno:Reload"
#define CMD_SID_BASICIDE_RENAMECURRENT              ".uno:RenameCurrent"
#define CMD_SID_DOCTEMPLATE                         ".uno:SaveAsTemplate"
#define CMD_SID_SEARCH_DLG                          ".uno:SearchDialog"
#define CMD_SID_SHOW_BROWSER                        ".uno:ShowBrowser"
#define CMD_SID_STYLE_NEW_BY_EXAMPLE                ".uno:StyleNewByExample"
#define CMD_SID_INET_DLG                            ".uno:InternetDialog"

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-l10n_5.1.4.orig.tar.xz: libreoffice-5.1.4/include/sfx2/sfxcommands.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */
#ifndef INCLUDED_SFX2_SFXCOMMANDS_H
#define INCLUDED_SFX2_SFXCOMMANDS_H

#define CMD_SID_BROWSE_BACKWARD                     ".uno:BrowseBackward"
#define CMD_SID_BROWSE_FORWARD                      ".uno:BrowseForward"
#define CMD_SID_CLOSEWIN                            ".uno:CloseWin"
#define CMD_SID_COPY                                ".uno:Copy"
#define CMD_SID_CUT                                 ".uno:Cut"
#define CMD_SID_DELETE                              ".uno:Delete"
#define CMD_SID_BASICIDE_DELETECURRENT              ".uno:DeleteCurrent"
#define CMD_SID_STYLE_DESIGNER                      ".uno:DesignerDialog"
#define CMD_SID_EDITDOC                             ".uno:EditDoc"
#define CMD_SID_STYLE_EDIT                          ".uno:EditStyle"
#define CMD_SID_WIN_FULLSCREEN                      ".uno:FullScreen"
#define CMD_SID_BASICIDE_HIDECURPAGE                ".uno:HideCurPage"
#define CMD_SID_BASICIDE_MODULEDLG                  ".uno:ModuleDialog"
#define CMD_SID_BASICIDE_NEWDIALOG                  ".uno:NewDialog"
#define CMD_SID_BASICIDE_NEWMODULE                  ".uno:NewModule"
#define CMD_SID_OPENDOC                             ".uno:Open"
#define CMD_SID_GALLERY_BG_BRUSH                    ".uno:BackgroundImage"
#define CMD_SID_PASTE                               ".uno:Paste"
#define CMD_SID_PASTE_SPECIAL                       ".uno:PasteSpecial"
#define CMD_SID_PASTE_UNFORMATTED                   ".uno:PasteUnformatted"
#define CMD_SID_PASTE_ONLY                          ".uno:PasteOnly"
#define CMD_SID_PASTE_ONLY_VALUE                    ".uno:PasteOnlyValue"
#define CMD_SID_PASTE_ONLY_TEXT                     ".uno:PasteOnlyText"
#define CMD_SID_PASTE_ONLY_FORMULA                  ".uno:PasteOnlyFormula"
#define CMD_SID_PRINTPREVIEW                        ".uno:PrintPreview"
#define CMD_SID_RELOAD                              ".uno:Reload"
#define CMD_SID_BASICIDE_RENAMECURRENT              ".uno:RenameCurrent"
#define CMD_SID_UNICODE_NOTATION_TOGGLE             ".uno:UnicodeNotationToggle"

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
